filter

package
v0.0.0-...-59f1789 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 14, 2016 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AppendBaseDirs

func AppendBaseDirs(bases []string, patterns []string) []string

AppendBaseDirs traverses a slice of patterns, and appends them to the bases list. The result of the append operation is a minimal set - that is, paths that are redundant because an enclosing path is already included are removed.

func BaseDir

func BaseDir(pattern string) string

BaseDir returns the base directory for a match pattern

func Files

func Files(files []string, includePatterns []string, excludePatterns []string) ([]string, error)

Files filters an array of files. At least ONE include pattern must match, and NONE of the exclude patterns must match.

func Find

func Find(root string, includePatterns []string, excludePatterns []string) ([]string, error)

Find all files under the root that match the specified patterns. All arguments and returned paths are slash-delimited.

Types

This section is empty.

Jump to