Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppendBaseDirs ¶
AppendBaseDirs traverses a slice of patterns, and appends them to the bases list. The result of the append operation is a minimal set - that is, paths that are redundant because an enclosing path is already included are removed.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.